//construct the duet enclosure to be deeper, controlled by parameter depth
//incorporate stand off for the board mount
//provide additional screw holes so the duet can be mounted further away from the Z axis
//round corners
//based on the original ormerod stl
include <MCAD/regular_shapes.scad>;
//%translate([0,0,0])cube([200,200,1],center=true); //build platform
$fn=100;
depth=14;
heightB=3;//height of board fixing stand-off
heightF=1;//height of extra enclosure fixings
wall=2; //wall thickness
CornerHeight=depth+19;
module box(){
		difference(){
	union(){	
		translate([-72,-55.3,-7.2])import("duet-enclosure.stl",center=true);  
		translate([-71.2,-54,0])cube([131,108,depth]);//solid base
		}
			translate([-5.5,0,depth-6])cube([125,102,depth+wall*2],center=true);//main cutout
			}//end of difference main cutout
		}

module RoundCorner(){
union(){
difference(){
rotate([0,-90,0])cube([CornerHeight,3,3]);
translate([1.5,1.5,-0.1])rotate([0,-90,0])cube([CornerHeight+0.3,3,3]);
}
translate([-1.5,1.5,0])cylinder(h=CornerHeight,r=1.5);
}
}
//end of module RoundCorner

module corners(){
	translate([60,52,0])RoundCorner();//lower left corner
	translate([-68.6,54.5,0])rotate([0,0,90])RoundCorner();//lower right corner
	translate([56.9,-54.8,0])rotate([0,0,-90])RoundCorner();//upper left corner
	translate([-71.5,-51.6,0])rotate([0,0,180])RoundCorner();//upper right corner
			}
module fillin(){
	translate([-71.1,-22,depth])cube([3,33,12]);//SD fillin
	translate([-71.1,-46,depth+2.7])cube([3,22,16]);//ethernet fillin
	translate([-71.1,-46,depth+6.7])cube([2,22,16]);//ethernet fillin
	translate([57,-7,depth])cube([2.9,22,12]);//power connector fillin
	translate([66,26,0]) cylinder(h=4,r=5);//outside screw fitting
	translate([60,17,0])cube([6,18,3.9]);//base of screw fitting

			}//end of fillin module

module connector_cutout(){
	translate([-75,-21,wall*3])cube([16,31,10]);//SD cutout
	translate([-75,-45,wall*3])cube([10,20,16]);//ethernet cutout
	translate([56,-6,wall*3])cube([5,20,10]);//power connector cutout
	translate([65.5,36,-0.1]) cylinder(h=5,r=5);//screw fitting outside curve
	translate([65.5,16,-0.1]) cylinder(h=5,r=5);//screw fitting outside curve
	translate([-59.5,49,3])cube([106,6,depth+21]);//lower cutout
	translate([59,17,depth-2])cube([12,18,7]);//removal of old external screw fitting
	}//end of module connectors cutout

module screw_cutout(){
		translate([66,26,-1])cylinder(h=7,r=2);//outside screw hole
		translate([66,26,1.1])cylinder(3,1,4);//outside screw countersink
	}//end of difference screw hole cutouts

module fixings(){
difference(){
union(){
translate([-64.5,45.5,0])cube([119,8,heightF+wall]);//lower left fillin
translate([52.5,45,0])cylinder(h=heightB+wall,r=5.5);//lower left post
translate([47.5,45,0])cube([10,8,heightB+wall]);//lower left post fillin
translate([-62.5,45,0])cylinder(h=heightB+wall,r=5.5);//lower right post1
translate([-68.5,45,0])cube([9.5,8,heightB+wall]);//lower right post fillin
translate([-52.5,45,0])cylinder(h=heightF+wall,r=5.5);//lower right post2
translate([-60,45.5,0])cube([9,7,heightF+wall]);//additional hole fillin
translate([-42.5,45,0])cylinder(h=heightF+wall,r=5.5);//lower right post3
translate([-32.5,45,0])cylinder(h=heightF+wall,r=5.5);//lower right post4
translate([-22.5,45,0])cylinder(h=heightF+wall,r=5.5);//lower right post5
translate([52.5,-46,0])cylinder(h=heightB+wall,r=5.5);//upper left post
translate([47.5,-52,0])cube([10,8,heightB+wall]);//upper left post fillin
translate([-62.5,-46,0])cylinder(h=heightB+wall,r=5.5);//upper right post
translate([-68.5,-52,])cube([10,8,heightB+wall]);//upper right post fillin
	translate([58.9,17,depth-2])cube([1,18,7]);
}//end of union
//start of difference

		translate([52.5,45,-1])cylinder(h=8,r=1.6);//lower left screw hole
		translate([-62.5,45,-1])cylinder(h=8,r=1.6);//lower right screw hole1
		translate([-52.5,45,-1])cylinder(h=8,r=1.6);//lower right screw hole2
		translate([-52.5,45,1.1])cylinder(heightF+1,0,5);//lower right hole2 countersunk
		translate([-42.5,45,-1])cylinder(h=8,r=1.6);//lower right screw hole3
		translate([-42.5,45,1.1])cylinder(heightF+1,0,5);//lower right hole3 countersunk
		translate([-32.5,45,-1])cylinder(h=8,r=1.6);//lower right screw hole4
		translate([-32.5,45,1.1])cylinder(heightF+1,0,5);//lower right hole4 countersunk
		translate([-22.5,45,-1])cylinder(h=8,r=1.6);//lower right screw hole5
		translate([-22.5,45,1.1])cylinder(heightF+1,0,5);//lower right hole5 countersunk
		translate([52.5,-46,-1])cylinder(h=8,r=1.6);//upper left screw hole
		translate([-62.5,-46,-1])cylinder(h=8,r=1.6);//upper right screw hole
}//end of difference
}//end of fixings
fixings ();



//Main Program
	module addin(){
	union(){
	box();
	corners();
	fixings();
	fillin();
	}
	}//end module addin

		module cutout(){
		difference(){
		connector_cutout();
		}
		}//end module cutout

			difference(){
			addin();{
			cutout();
			screw_cutout();
			}
			}
